@@ -64,7 +64,7 @@ See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
 The socket is set to non-blocking mode.
 
-=head3 new Options
+Options:
 
 =over 2
 
@@ -74,8 +74,6 @@ The socket is set to non-blocking mode.
 
 =item * Proto : Int
 
-=item * Blocking : Int
-
 =item * Timeout : Double
 
 =item * Listen : Int
@@ -110,10 +108,6 @@ Gets the L</"Proto"> field.
 
 Gets the L</"Timeout"> field.
 
-=head2 new_from_instance
-
-  method new_from_instance : IO::Socket ($options : object[] = undef);
-
 =head2 peername
 
   method peername : Sys::Socket::Sockaddr ();
@@ -122,16 +116,6 @@ Gets the L</"Timeout"> field.
 
   method DESTROY : void ();
 
-=head2 init
-
-  protected method init : void ($options : object[] = undef);
-
-=head2 connect
-
-  method connect : void ($address : Sys::Socket::Sockaddr);
-
-See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
-
 =head2 recv
 
   method recv : int ($buffer : mutable string, $length : int = -1, $flags : int = 0, $buf_offset : int = 0);
@@ -150,16 +134,6 @@ See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
   method fileno : int (); return $self->{fd}; }
 
-=head2 listen
-
-  method listen : void ($queue : int = 5);
-
-=head2 bind
-
-  method bind : void ($address : Sys::Socket::Sockaddr);
-
-See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
-
 =head2 sockname
 
   method sockname : Sys::Socket::Sockaddr ();
@@ -188,23 +162,6 @@ See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
 See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
-=head2 socket
-
-  method socket : void ($domain : int, $type : int, $protocol : int = 0);
-
-=head2 socketpair
-
-  method socketpair : int[] ($domain : int, $type : int, $protocol : int);
-
-=head2 accept
-
-  method accept : IO::Socket ($io_socket_builder : IO::Socket::Builder = undef, $peer_ref : Sys::Socket::Sockaddr[] = undef);
-
-See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
-
-See also L<IO::Socket::Builder|SPVM::IO::Socket::Builder>.
-
-
 =head2 peerport
 
   method peerport : int ();
